==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXUPnP.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUPnP;no warnings;($pfProtocol=(""));($portInternal=(""));(
$portExternal=(""));($protocol="\x55\x44\x50");($duration=(0x12e8+ 992-0x1470));
sub BEGIN{require warnings;do{"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub 
addRule{if ((not ($GLOBAL::EnableUPnP))){Logger::debug (
"\x4e\x58\x55\x50\x6e\x50\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x20\x69\x6e\x20\x6e\x6f\x64\x65\x20\x63\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e\x2e"
);return ((0x03f0+ 4107-0x13fb));}Logger::debug (((((((((
"\x54\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal)."\x20\x28").$protocol).
"\x29\x20\x5b").$duration)."\x5d\x2e"));if ((($portInternal eq (""))or (
$portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x61\x64\x64\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x075d+ 767-0x0a5c));}(my (@command)=());(my ($std_err,$std_out,
$ret_val)=((""),(""),("")));if (((not (defined ($pfProtocol)))or ($pfProtocol eq
 ("")))){Logger::debug (
"\x41\x75\x74\x6f\x64\x65\x74\x65\x63\x74\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c"
);(@command=($GLOBAL::CommandNXUPNP,"\x2d\x70"));(($std_err,$std_out,$ret_val)=
main::run_command ((\@command)));($pfProtocol=$std_out);chomp ($pfProtocol);}
else{Logger::debug ((
"\x50\x72\x69\x76\x69\x64\x65\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20"
.$pfProtocol));($ret_val=(0x15f2+ 1142-0x1a67));}if (($ret_val eq "\x30")){if ((
($pfProtocol eq "\x75\x70\x6e\x70")or ($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70"
))){if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=($GLOBAL::CommandNXUPNP,
"\x2d\x58",$pfProtocol,"\x2d\x72",$portExternal,$protocol,$duration));}else{(
@command=($GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portInternal,$protocol,
$duration));}(($std_err,$std_out,$ret_val)=main::run_command ((\@command)));if (
($ret_val eq "\x31")){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x6e\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0cf2+ 6012-0x246e));}else{Logger::debug (((((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x61\x64\x64\x65\x64\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal).
"\x2c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20").$protocol)."\x2e"));return (
(0x1009+ 3161-0x1c62));}}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x2e"
);return ((0x0292+ 2791-0x0d79));}}else{Logger::warning (
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20\x6e\x6f\x74\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);return ((0x01aa+ 1120-0x060a));}return ((0x0bed+ 4858-0x1ee7));}sub 
refreshRule{addRule ($portExternal,$portNternal,$protocol,$duration,$pfProtocol)
;}sub removeRule{if ((not ($GLOBAL::EnableUPnP))){return ((0x1dd6+ 1864-0x251e))
;}if ((($portInternal eq (""))or ($portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x1cd9+ 340-0x1e2d));}Logger::debug (((((((
"\x52\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x20\x5b").$pfProtocol)."\x5d\x2e"))
;(my (@command)=());if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x64",$portExternal,$protocol
));}elsif (($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portExternal,$rotocol,
(0x1bc4+ 920-0x1f5c)));}else{Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20\x77\x72\x6f\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b"
.$pfProtocol)."\x5d\x2e"));return ((0x03d9+ 2041-0x0bd1));}(my ($std_err,
$std_out,$ret_val)=main::run_command ((\@command)));if (($ret_val eq "\x30")){
Logger::warning (((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x72\x65\x6d\x6f\x76\x65\x64\x3a\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x2e"));return (
(0x0dfd+ 2498-0x17bf));}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x1839+ 875-0x1ba3));}return ((0x21b7+ 1126-0x261d));}sub 
setportInternal{(my $port=shift (@_));($portInternal=$port);}sub setportExternal
{(my $port=shift (@_));($portExternal=$port);}sub handleUdpDescriptor{(my $line=
shift (@_));Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x70\x61\x73\x73\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x27"
.$line)."\x27\x2e"));main::parse_arguments ($line);main::nxwrite (
main::nxgetSTDOUT (),"\x72\x65\x61\x64\x79\x0a");(my $pid=$GLOBAL::parameters{
"\x75\x64\x70\x50\x69\x64"});(my $fd=$GLOBAL::parameters{"\x75\x64\x70\x46\x64"}
);(my $path=$GLOBAL::parameters{"\x75\x64\x70\x50\x61\x74\x68"});(my $cookie=
$GLOBAL::parameters{"\x75\x64\x70\x43\x6f\x6f\x6b\x69\x65"});(my $udpHandle=
Common::NXDescriptor::acquire ($pid,$fd,$path,$cookie));if (($udpHandle<
(0x0bb0+ 4854-0x1ea6))){Logger::warning (((((
"\x4e\x58\x55\x64\x70\x3a\x20\x46\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x61\x63\x71\x75\x69\x72\x65\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x72\x6f\x6d\x20\x73\x65\x72\x76\x65\x72\x20\x27"
.$pid)."\x27\x20\x61\x6e\x64\x20\x70\x61\x74\x68\x20\x27").$path)."\x27\x2e"));}
return ($udpHandle);}return ((0x0957+ 3733-0x17eb));

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXUPnP.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUPnP;no warnings;($pfProtocol=(""));($portInternal=(""));(
$portExternal=(""));($protocol="\x55\x44\x50");($duration=(0x0f9a+ 438-0x0ef8));
sub BEGIN{require warnings;do{"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub 
addRule{if ((not ($GLOBAL::EnableUPnP))){Logger::debug (
"\x4e\x58\x55\x50\x6e\x50\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x20\x69\x6e\x20\x6e\x6f\x64\x65\x20\x63\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e\x2e"
);return ((0x0c3d+ 5303-0x20f4));}Logger::debug (((((((((
"\x54\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal)."\x20\x28").$protocol).
"\x29\x20\x5b").$duration)."\x5d\x2e"));if ((($portInternal eq (""))or (
$portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x61\x64\x64\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x1494+ 403-0x1627));}(my (@command)=());(my ($std_err,$std_out,
$ret_val)=((""),(""),("")));if (((not (defined ($pfProtocol)))or ($pfProtocol eq
 ("")))){Logger::debug (
"\x41\x75\x74\x6f\x64\x65\x74\x65\x63\x74\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c"
);(@command=($GLOBAL::CommandNXUPNP,"\x2d\x70"));(($std_err,$std_out,$ret_val)=
main::run_command ((\@command)));($pfProtocol=$std_out);chomp ($pfProtocol);}
else{Logger::debug ((
"\x50\x72\x69\x76\x69\x64\x65\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20"
.$pfProtocol));($ret_val=(0x01e7+ 1753-0x08bf));}if (($ret_val eq "\x30")){if ((
($pfProtocol eq "\x75\x70\x6e\x70")or ($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70"
))){if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=($GLOBAL::CommandNXUPNP,
"\x2d\x58",$pfProtocol,"\x2d\x72",$portExternal,$protocol,$duration));}else{(
@command=($GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portInternal,$protocol,
$duration));}(($std_err,$std_out,$ret_val)=main::run_command ((\@command)));if (
($ret_val eq "\x31")){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x6e\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0d50+ 838-0x1096));}else{Logger::debug (((((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x61\x64\x64\x65\x64\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal).
"\x2c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20").$protocol)."\x2e"));return (
(0x0bb2+ 6684-0x25ce));}}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x2e"
);return ((0x0152+ 6886-0x1c38));}}else{Logger::warning (
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20\x6e\x6f\x74\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);return ((0x1f7b+ 540-0x2197));}return ((0x098c+ 300-0x0ab8));}sub refreshRule{
addRule ($portExternal,$portNternal,$protocol,$duration,$pfProtocol);}sub 
removeRule{if ((not ($GLOBAL::EnableUPnP))){return ((0x1a1c+ 2106-0x2256));}if (
(($portInternal eq (""))or ($portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x0014+ 3552-0x0df4));}Logger::debug (((((((
"\x52\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x20\x5b").$pfProtocol)."\x5d\x2e"))
;(my (@command)=());if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x64",$portExternal,$protocol
));}elsif (($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portExternal,$rotocol,
(0x0f89+ 5964-0x26d5)));}else{Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20\x77\x72\x6f\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b"
.$pfProtocol)."\x5d\x2e"));return ((0x0807+ 5495-0x1d7d));}(my ($std_err,
$std_out,$ret_val)=main::run_command ((\@command)));if (($ret_val eq "\x30")){
Logger::warning (((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x72\x65\x6d\x6f\x76\x65\x64\x3a\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x2e"));return (
(0x1644+ 2121-0x1e8d));}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0f30+ 3429-0x1c94));}return ((0x0b9b+ 6156-0x23a7));}sub 
setportInternal{(my $port=shift (@_));($portInternal=$port);}sub setportExternal
{(my $port=shift (@_));($portExternal=$port);}sub handleUdpDescriptor{(my $line=
shift (@_));Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x70\x61\x73\x73\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x27"
.$line)."\x27\x2e"));main::parse_arguments ($line);main::nxwrite (
main::nxgetSTDOUT (),"\x72\x65\x61\x64\x79\x0a");(my $pid=$GLOBAL::parameters{
"\x75\x64\x70\x50\x69\x64"});(my $fd=$GLOBAL::parameters{"\x75\x64\x70\x46\x64"}
);(my $path=$GLOBAL::parameters{"\x75\x64\x70\x50\x61\x74\x68"});(my $cookie=
$GLOBAL::parameters{"\x75\x64\x70\x43\x6f\x6f\x6b\x69\x65"});(my $udpHandle=
Common::NXDescriptor::acquire ($pid,$fd,$path,$cookie));if (($udpHandle<
(0x0d7d+ 3567-0x1b6c))){Logger::warning (((((
"\x4e\x58\x55\x64\x70\x3a\x20\x46\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x61\x63\x71\x75\x69\x72\x65\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x72\x6f\x6d\x20\x73\x65\x72\x76\x65\x72\x20\x27"
.$pid)."\x27\x20\x61\x6e\x64\x20\x70\x61\x74\x68\x20\x27").$path)."\x27\x2e"));}
return ($udpHandle);}return ((0x0855+ 2934-0x13ca));
